@@ -16,8 +16,7 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 
@@ -254,10 +253,18 @@ gth_file_list_drag_data_received (GtkWidget        *file_view,
 	GthBrowser  *browser = user_data;
 	gboolean     success = FALSE;
 	char       **uris;
-	GList       *file_list;
+	GList       *selected_files;
 
 	g_signal_stop_emission_by_name (file_view, "drag-data-received");
 
+	/*
+	if ((gdk_drag_context_get_suggested_action (context) == GDK_ACTION_COPY)
+	    || (gdk_drag_context_get_suggested_action (context) == GDK_ACTION_MOVE))
+	{
+		success = TRUE;
+	}
+	*/
+
 	if ((context->suggested_action == GDK_ACTION_COPY)
 	    || (context->suggested_action == GDK_ACTION_MOVE))
 	{
@@ -267,20 +274,28 @@ gth_file_list_drag_data_received (GtkWidget        *file_view,
 	gtk_drag_finish (context, success, FALSE, time);
 
 	uris = gtk_selection_data_get_uris (selection_data);
-	file_list = _g_file_list_new_from_uriv (uris);
-	if (file_list != NULL) {
+	selected_files = _g_file_list_new_from_uriv (uris);
+	if (selected_files != NULL) {
 		if (gtk_drag_get_source_widget (context) == file_view) {
+			GList       *file_data_list;
+			GList       *visible_files;
 			BrowserData *data;
 			GthTask     *task;
 
+			file_data_list = gth_file_store_get_visibles (gth_browser_get_file_store (browser));
+			visible_files = gth_file_data_list_to_file_list (file_data_list);
+
 			data = g_object_get_data (G_OBJECT (browser), BROWSER_DATA_KEY);
 			task = gth_reorder_task_new (gth_browser_get_location_source (browser),
 						     gth_browser_get_location_data (browser),
-						     file_list,
+						     visible_files,
+						     selected_files,
 						     data->drop_pos);
 			gth_browser_exec_task (browser, task, FALSE);
 
 			g_object_unref (task);
+			_g_object_list_unref (visible_files);
+			_g_object_list_unref (file_data_list);
 		}
 		else {
 			GthFileSource *file_source;
@@ -288,6 +303,7 @@ gth_file_list_drag_data_received (GtkWidget        *file_view,
 			gboolean       move;
 
 			file_source = gth_browser_get_location_source (browser);
+			/*move = gdk_drag_context_get_suggested_action (context) == GDK_ACTION_MOVE;*/
 			move = context->suggested_action == GDK_ACTION_MOVE;
 			if (move && ! gth_file_source_can_cut (file_source)) {
 				GtkWidget *dialog;
@@ -316,7 +332,7 @@ gth_file_list_drag_data_received (GtkWidget        *file_view,
 				task = gth_copy_task_new (file_source,
 							  gth_browser_get_location_data (browser),
 							  move,
-							  file_list);
+							  selected_files);
 				gth_browser_exec_task (browser, task, FALSE);
 
 				g_object_unref (task);
@@ -324,7 +340,7 @@ gth_file_list_drag_data_received (GtkWidget        *file_view,
 		}
 	}
 
-	_g_object_list_unref (file_list);
+	_g_object_list_unref (selected_files);
 	g_strfreev (uris);
 }
 
@@ -393,13 +409,17 @@ gth_file_list_drag_motion (GtkWidget      *file_view,
 	}
 
 	if ((gtk_drag_get_source_widget (context) == file_view) && gth_file_source_is_reorderable (gth_browser_get_location_source (browser))) {
+		GtkAllocation allocation;
+
 		gdk_drag_status (context, GDK_ACTION_MOVE, time);
 		gth_file_view_set_drag_dest_pos (GTH_FILE_VIEW (file_view), context, x, y, time, &data->drop_pos);
 
+		gtk_widget_get_allocation (file_view, &allocation);
+
 		if (y < 10)
 			data->scroll_diff = - (10 - y);
-		else if (y > file_view->allocation.height - 10)
-			data->scroll_diff = (10 - (file_view->allocation.height - y));
+		else if (y > allocation.height - 10)
+			data->scroll_diff = (10 - (allocation.height - y));
 		else
 			data->scroll_diff = 0;
 
@@ -995,13 +1015,16 @@ fm__gth_browser_file_list_key_press_cb (GthBrowser  *browser,
 					GdkEventKey *event)
 {
 	gpointer  result = NULL;
+	guint     modifiers;
 	GList    *items;
 	GList    *file_data_list;
 	GList    *file_list;
 
-	switch (gdk_keyval_to_lower (event->keyval)) {
+	modifiers = gtk_accelerator_get_default_mod_mask ();
+
+	switch (event->keyval) {
 	case GDK_g:
-		if (! (event->state & GDK_CONTROL_MASK) && ! (event->state & GDK_SHIFT_MASK)) {
+		if ((event->state & modifiers) == 0) {
 			items = gth_file_selection_get_selected (GTH_FILE_SELECTION (gth_browser_get_file_list_view (browser)));
 			file_data_list = gth_file_list_get_files (GTH_FILE_LIST (gth_browser_get_file_list (browser)), items);
 			file_list = gth_file_data_list_to_file_list (file_data_list);
@@ -1015,11 +1038,11 @@ fm__gth_browser_file_list_key_press_cb (GthBrowser  *browser,
 		break;
 
 	case GDK_Delete:
-		if (! (event->state & GDK_CONTROL_MASK) && ! (event->state & GDK_SHIFT_MASK)) {
+		if ((event->state & modifiers) == 0) {
 			gth_browser_activate_action_edit_trash (NULL, browser);
 			result = GINT_TO_POINTER (1);
 		}
-		else if (! (event->state & GDK_CONTROL_MASK) && (event->state & GDK_SHIFT_MASK)) {
+		else if ((event->state & modifiers) == GDK_SHIFT_MASK) {
 			gth_browser_activate_action_edit_delete (NULL, browser);
 			result = GINT_TO_POINTER (1);
 		}
