@@ -16,8 +16,7 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <config.h>
@@ -162,8 +161,6 @@ import_dialog_response_cb (GtkDialog *dialog,
 				GthSubfolderType     subfolder_type;
 				GthSubfolderFormat   subfolder_format;
 				char                *custom_format;
-				gboolean             overwrite_files;
-				gboolean             adjust_orientation;
 				char               **tags;
 				int                  i;
 				GthTask             *task;
@@ -173,8 +170,6 @@ import_dialog_response_cb (GtkDialog *dialog,
 				subfolder_format = eel_gconf_get_enum (PREF_IMPORT_SUBFOLDER_FORMAT, GTH_TYPE_SUBFOLDER_FORMAT, GTH_SUBFOLDER_FORMAT_YYYYMMDD);
 				single_subfolder = eel_gconf_get_boolean (PREF_IMPORT_SUBFOLDER_SINGLE, FALSE);
 				custom_format = eel_gconf_get_string (PREF_IMPORT_SUBFOLDER_CUSTOM_FORMAT, "");
-				overwrite_files = eel_gconf_get_boolean (PREF_IMPORT_OVERWRITE, FALSE);
-				adjust_orientation = eel_gconf_get_boolean (PREF_IMPORT_ADJUST_ORIENTATION, FALSE);
 
 				tags = g_strsplit ((album->keywords != NULL ? album->keywords : ""), ",", -1);
 				for (i = 0; tags[i] != NULL; i++)
@@ -190,8 +185,8 @@ import_dialog_response_cb (GtkDialog *dialog,
 							    (album->title != NULL ? album->title : ""),
 							    tags,
 							    FALSE,
-							    overwrite_files,
-							    adjust_orientation);
+							    FALSE,
+							    FALSE);
 				gth_browser_exec_task (data->browser, task, FALSE);
 				gtk_widget_destroy (data->dialog);
 
@@ -750,7 +745,8 @@ list_photos_ready_cb (GObject      *source_object,
 	GList            *list;
 	GList            *scan;
 
-	gth_task_dialog (GTH_TASK (data->conn), TRUE, NULL);
+	if (data->conn != NULL)
+		gth_task_dialog (GTH_TASK (data->conn), TRUE, NULL);
 	_g_object_list_unref (data->photos);
 	data->photos = picasa_web_service_list_albums_finish (picasaweb, result, &error);
 	if (error != NULL) {
@@ -799,6 +795,8 @@ album_combobox_changed_cb (GtkComboBox *widget,
 			    ALBUM_DATA_COLUMN, &data->album,
 			    -1);
 
+	gth_import_preferences_dialog_set_event (GTH_IMPORT_PREFERENCES_DIALOG (data->preferences_dialog), data->album->title);
+
 	gth_task_dialog (GTH_TASK (data->conn), FALSE, NULL);
 	picasa_web_service_list_photos (data->picasaweb,
 					data->album,
@@ -895,16 +893,6 @@ file_list_selection_changed_cb (GtkIconView *iconview,
 }
 
 
-static void
-preferences_button_clicked_cb (GtkWidget  *widget,
-			       DialogData *data)
-{
-	gth_import_preferences_dialog_set_event (GTH_IMPORT_PREFERENCES_DIALOG (data->preferences_dialog),
-						 (data->album != NULL) ? data->album->title : "");
-	gtk_window_present (GTK_WINDOW (data->preferences_dialog));
-}
-
-
 void
 dlg_import_from_picasaweb (GthBrowser *browser)
 {
@@ -967,6 +955,13 @@ dlg_import_from_picasaweb (GthBrowser *browser)
 	data->preferences_dialog = gth_import_preferences_dialog_new ();
 	gtk_window_set_transient_for (GTK_WINDOW (data->preferences_dialog), GTK_WINDOW (data->dialog));
 
+	gtk_box_pack_start (GTK_BOX (GET_WIDGET ("destination_button_box")),
+			    gth_import_destination_button_new (GTH_IMPORT_PREFERENCES_DIALOG (data->preferences_dialog)),
+			    TRUE,
+			    TRUE,
+			    0);
+	gtk_widget_show_all (GET_WIDGET ("destination_button_box"));
+
 	/* Set the signals handlers. */
 
 	g_signal_connect (G_OBJECT (data->dialog),
@@ -993,12 +988,9 @@ dlg_import_from_picasaweb (GthBrowser *browser)
 			  "selection_changed",
 			  G_CALLBACK (file_list_selection_changed_cb),
 			  data);
-	g_signal_connect (GET_WIDGET ("preferences_button"),
-			  "clicked",
-			  G_CALLBACK (preferences_button_clicked_cb),
-			  data);
 
 	update_selection_status (data);
+	gth_import_preferences_dialog_set_event (GTH_IMPORT_PREFERENCES_DIALOG (data->preferences_dialog), "");
 
 	data->accounts = picasa_web_accounts_load_from_file (&data->email);
 	auto_select_account (data);
