@@ -16,8 +16,7 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <config.h>
@@ -119,9 +118,6 @@ gth_file_properties_real_set_file (GthPropertyView *base,
 		if ((info->flags & GTH_METADATA_ALLOW_IN_PROPERTIES_VIEW) != GTH_METADATA_ALLOW_IN_PROPERTIES_VIEW)
 			continue;
 
-		if ((info->display_name == NULL) || (strncmp (info->display_name, "0x", 2) == 0))
-			continue;
-
 		value = gth_file_data_get_attribute_as_string (file_data, info->id);
 		if ((value == NULL) || (*value == '\0'))
 			continue;
@@ -247,12 +243,11 @@ copy_menu_item_activate_cb (GtkMenuItem *menuitem,
 	if (! gtk_tree_selection_get_selected (GTK_TREE_SELECTION (gtk_tree_view_get_selection (GTK_TREE_VIEW (self->priv->tree_view))), &model, &iter))
 		return;
 
-	gtk_tree_model_get (model, &iter,
-			    VALUE_COLUMN, &value,
-			    -1);
-	gtk_clipboard_set_text (gtk_clipboard_get_for_display (gtk_widget_get_display (GTK_WIDGET (menuitem)), GDK_SELECTION_CLIPBOARD),
-			        value,
-			        -1);
+	gtk_tree_model_get (model, &iter, VALUE_COLUMN, &value, -1);
+	if (value != NULL)
+		gtk_clipboard_set_text (gtk_clipboard_get_for_display (gtk_widget_get_display (GTK_WIDGET (menuitem)), GDK_SELECTION_CLIPBOARD),
+					value,
+					-1);
 
 	g_free (value);
 }
@@ -295,6 +290,24 @@ tree_view_button_press_event_cb (GtkWidget      *widget,
 }
 
 
+static gboolean
+tree_view_popup_menu_cb (GtkWidget *widget,
+			 gpointer   user_data)
+{
+	GthFileProperties *self = user_data;
+
+	gtk_menu_popup (GTK_MENU (self->priv->popup_menu),
+			NULL,
+			NULL,
+			NULL,
+			NULL,
+			0,
+			gtk_get_current_event_time ());
+
+	return TRUE;
+}
+
+
 static void
 gth_file_properties_init (GthFileProperties *self)
 {
@@ -352,6 +365,10 @@ gth_file_properties_init (GthFileProperties *self)
 			  "button-press-event",
 			  G_CALLBACK (tree_view_button_press_event_cb),
 			  self);
+	g_signal_connect (self->priv->tree_view,
+			  "popup-menu",
+			  G_CALLBACK (tree_view_popup_menu_cb),
+			  self);
 
 	/**/
 
